==> django-kmuhelper-1.5.tar.gz: django-kmuhelper-1.5/README.md <==
# KMUHelper

[![PyPI](https://img.shields.io/pypi/v/django-kmuhelper)](https://pypi.org/project/django-kmuhelper)
[![PyPI - Django Version](https://img.shields.io/pypi/djversions/django-kmuhelper)](https://pypi.org/project/django-kmuhelper)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/django-kmuhelper)](https://pypi.org/project/django-kmuhelper)
[![PyPI - License](https://img.shields.io/pypi/l/django-kmuhelper)](https://github.com/rafaelurben/django-kmuhelper/blob/master/LICENSE)

[![GitHub code size in bytes](https://img.shields.io/github/languages/code-size/rafaelurben/django-kmuhelper)](https://github.com/rafaelurben/django-kmuhelper)
[![GitHub lines of code](https://img.shields.io/tokei/lines/github.com/rafaelurben/django-kmuhelper)](https://github.com/rafaelurben/django-kmuhelper)
[![GitHub issues](https://img.shields.io/github/issues/rafaelurben/django-kmuhelper)](https://github.com/rafaelurben/django-kmuhelper/issues)
[![GitHub pull requests](https://img.shields.io/github/issues-pr/rafaelurben/django-kmuhelper)](https://github.com/rafaelurben/django-kmuhelper/pulls)

[![CodeFactor](https://www.codefactor.io/repository/github/rafaelurben/django-kmuhelper/badge)](https://www.codefactor.io/repository/github/rafaelurben/django-kmuhelper)

Der KMUHelper ist, wie der Name schon sagt, ein Helfer für KMU - hauptsächlich jedoch für Schweizer, da der Hauptgrund für
die Entwicklung dieser Djangoapp die neue Schweizer QR-Rechnung ist.

Diverse Infos über den KMUHelper gibt's auf der [Webseite](https://rafaelurben.github.io/kmuhelper/) sowie in der [Dokumentation](https://rafaelurben.github.io/django-kmuhelper/)

## Änderungen und Feedback

- [Diskussionen](https://github.com/rafaelurben/django-kmuhelper/discussions) - Fragen und Ideen
- [Issues](https://github.com/rafaelurben/django-kmuhelper/issues) - Bugs und Feature requests
- [Kontakt](https://rafaelurben.github.io/kmuhelper/kontakt) - Dringende Anfragen und Sicherheitslücken

Geplante Änderungen und aktuelle Programmierfortschritte können im [Projekt-Board](https://github.com/rafaelurben/django-kmuhelper/projects/1) gefunden werden.

## Installation

Siehe [hier](https://rafaelurben.github.io/django-kmuhelper/installation).

## English / Translations

There is currently no english translation planned because this app's main focus is Switzerland with it's QR invoice, so there's no point in an english translation, although I might consider creating a French translation.

==> django-kmuhelper-1.6.0.tar.gz: django-kmuhelper-1.6.0/README.md <==
# KMUHelper

[![PyPI](https://img.shields.io/pypi/v/django-kmuhelper)](https://pypi.org/project/django-kmuhelper)
[![PyPI - Django Version](https://img.shields.io/pypi/djversions/django-kmuhelper)](https://pypi.org/project/django-kmuhelper)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/django-kmuhelper)](https://pypi.org/project/django-kmuhelper)
[![PyPI - License](https://img.shields.io/pypi/l/django-kmuhelper)](https://github.com/rafaelurben/django-kmuhelper/blob/master/LICENSE)

[![GitHub code size in bytes](https://img.shields.io/github/languages/code-size/rafaelurben/django-kmuhelper)](https://github.com/rafaelurben/django-kmuhelper)
[![GitHub lines of code](https://img.shields.io/tokei/lines/github.com/rafaelurben/django-kmuhelper)](https://github.com/rafaelurben/django-kmuhelper)
[![GitHub issues](https://img.shields.io/github/issues/rafaelurben/django-kmuhelper)](https://github.com/rafaelurben/django-kmuhelper/issues)
[![GitHub pull requests](https://img.shields.io/github/issues-pr/rafaelurben/django-kmuhelper)](https://github.com/rafaelurben/django-kmuhelper/pulls)

[![CodeFactor](https://www.codefactor.io/repository/github/rafaelurben/django-kmuhelper/badge)](https://www.codefactor.io/repository/github/rafaelurben/django-kmuhelper)

Der KMUHelper ist, wie der Name schon sagt, ein Helfer für KMU - hauptsächlich jedoch für Schweizer, da der Hauptgrund für
die Entwicklung dieser Djangoapp die neue Schweizer QR-Rechnung ist.

Diverse Infos über den KMUHelper gibt's auf der [Webseite](https://rafaelurben.github.io/kmuhelper/) sowie in der [Dokumentation](https://rafaelurben.github.io/django-kmuhelper/)

## Änderungen und Feedback

Die neusten Änderungen können im [Änderungsprotokoll](https://github.com/rafaelurben/django-kmuhelper/releases) angesehen werden.

- [Diskussionen](https://github.com/rafaelurben/django-kmuhelper/discussions) - Fragen und Ideen
- [Issues](https://github.com/rafaelurben/django-kmuhelper/issues) - Bugs und Feature requests
- [Kontakt](mailto:kmuhelper@rafaelurben.ch) - Dringende Anfragen und Sicherheitslücken

Geplante Änderungen und aktuelle Programmierfortschritte können im [Projekt-Board](https://github.com/rafaelurben/django-kmuhelper/projects/1) gefunden werden.

## Installation

Siehe [hier](https://rafaelurben.github.io/django-kmuhelper/installation).

## English / Translations

There is currently no english translation planned because this app's main focus is Switzerland with its QR invoice, so there's no point in an english translation, although I might consider creating a French translation.
